const fs = require('fs-extra')
const path = require('path')
const templateDir = __dirname + '/template/'

const walk = (p, fileCallback, errCallback) => {
  fs.readdir(p, (err, files) => {

    if (err) {
      errCallback(err)
      return
    }

    files.forEach(file => {
      const fullPath = path.join(p, file)

      if (fs.statSync(fullPath).isDirectory()) {
        walk(fullPath, fileCallback)
      } else {
        fileCallback(fullPath)
      }
    })
  })
}

module.exports = (api) => {
  api.render('./template')

  let templates = []
  let originalFiles = []
  const fileCallback = path => {
    const simplePath = path.replace(templateDir, '')
    templates.push(simplePath)
  }
  const errCallback = err => console.log('Receive err:' + err)

  walk(templateDir, fileCallback, errCallback)

  api.postProcessFiles(files => {
    const fileList = Object.keys(files)
    const srcFileList = fileList.filter(file => /^src\//.test(file))
    originalFiles = srcFileList.filter(file => !templates.includes(file))
  })

  api.onCreateComplete(() => {
    originalFiles.forEach(file => {
      fs.remove(api.resolve(file))
    })
  })
}
